@@ -1,4 +1,5 @@
 import django_filters
+from extras.filters import TagFilter
 from netbox.filtersets import BaseFilterSet
 from utilities.filters import ContentTypeFilter
 
@@ -12,6 +13,8 @@ class NetBoxAttachmentFilterSet(BaseFilterSet):
     )
     created = django_filters.DateTimeFilter()
     content_type = ContentTypeFilter()
+    name = django_filters.CharFilter(lookup_expr="icontains")
+    tag = TagFilter()
 
     class Meta:
         model = NetBoxAttachment
